@@ -8,7 +8,7 @@
 # 特記事項:
 # なし
 #
-# Copyright (c) 2012-2020, NIPPON TELEGRAPH AND TELEPHONE CORPORATION
+# Copyright (c) 2012-2022, NIPPON TELEGRAPH AND TELEPHONE CORPORATION
 #
 #####################################################################
 package PGRex;
@@ -100,8 +100,8 @@ sub pacemaker_online{
     $results[1] = $? >> 8;
 
     $exit_code = $results[1];
-    # Pacemaker が起動している場合は $exit_code = 0 、起動していない場合は $exit_code = 107
-    if ($exit_code != 0 && $exit_code != 107){
+    # Pacemaker が起動している場合は $exit_code = 0 、起動していない場合は $exit_code = 1
+    if ($exit_code != 0 && $exit_code != 1){
         printlog("ERROR", COMMON_MS0001);
     }
 
@@ -130,8 +130,8 @@ sub pgrex_failed_action{
     $results[1] = $? >> 8;
 
     $exit_code = $results[1];
-    # Pacemaker が起動している場合は $exit_code = 0 、起動していない場合は $exit_code = 107
-    if ($exit_code != 0 && $exit_code != 107){
+    # Pacemaker が起動している場合は $exit_code = 0 、起動していない場合は $exit_code = 1
+    if ($exit_code != 0 && $exit_code != 1){
         printlog("ERROR", COMMON_MS0001);
     }
 
@@ -226,8 +226,8 @@ sub standby_running{
     ##
     # 以下の条件を満たしたとき結果を OK とする
     #   *  コマンド
-    #     「crm_resource -r <PrimaryリソースID> -W 2> /dev/null | grep " <マシンのホスト名> "」
-    #      の結果が"resource <PrimaryリソースID> is running on: <マシンのホスト名> "である
+    #     「crm_resource -r <PrimaryリソースID> -W 2> /dev/null | grep " <マシンのホスト名>"」
+    #      の結果が"resource <PrimaryリソースID> is running on: <マシンのホスト名>"である
     #   *  コマンド
     #     「crm_attribute -l forever -N <マシンのホスト名> --name <PostgreSQLのPrimitiveのリソースID>-data-status -G -q」
     #      の結果が"STREAMING|SYNC"である
@@ -236,11 +236,11 @@ sub standby_running{
     #      の結果が"HS:SYNC"である
     ##
 
-    $command = "$CRM_RESOURCE -r $primary_resource_id -W 2> /dev/null | $GREP \" $my_node \"";
+    $command = "$CRM_RESOURCE -r $primary_resource_id -W 2> /dev/null | $GREP \" $my_node\$\"";
     $result = `$command`;
     chomp $result;
 
-    if ($result ne "resource $primary_resource_id is running on: $my_node "){
+    if ($result ne "resource $primary_resource_id is running on: $my_node"){
         if ($error_code){
             $$error_code = 1;
         }
@@ -275,12 +275,12 @@ sub vip_running{
     # 以下の条件を満たしたとき結果を OK とする
     #   *  コマンド
     #     「crm_resource -r <リソースID> -W 2> /dev/null」
-    #      の結果が"resource <リソースID> is running on: <マシンのホスト名> "である
+    #      の結果が"resource <リソースID> is running on: <マシンのホスト名>"である
     ##
 
     $result = `$CRM_RESOURCE -r $resource_id -W 2> /dev/null`;
     chomp $result;
-    if ($result ne "resource $resource_id is running on: $my_node "){
+    if ($result ne "resource $resource_id is running on: $my_node"){
         return 0;
     }
 
@@ -299,18 +299,18 @@ sub stonith_running{
     #     「crm_resource -r <リソースID_1> -W 2> /dev/null」
     #     「crm_resource -r <リソースID_2> -W 2> /dev/null」
     #      のどちらも実行して、どちらかの結果が
-    #      "resource <指定したリソースID> is running on: <マシンのホスト名> "である
+    #      "resource <指定したリソースID> is running on: <マシンのホスト名>"である
     ##
 
     $result = `$CRM_RESOURCE -r $resource_id->[0] -W 2> /dev/null`;
     chomp $result;
-    if ($result eq "resource $resource_id->[0] is running on: $my_node "){
+    if ($result eq "resource $resource_id->[0] is running on: $my_node"){
         return 1;
     }
 
     $result = `$CRM_RESOURCE -r $resource_id->[1] -W 2> /dev/null`;
     chomp $result;
-    if ($result eq "resource $resource_id->[1] is running on: $my_node "){
+    if ($result eq "resource $resource_id->[1] is running on: $my_node"){
         return 1;
     }
 
@@ -329,17 +329,17 @@ sub ping_running{
     ##
     # 以下の条件を指定されたリソースの数だけ満たしたとき結果を OK とする
     #   *  コマンド
-    #     「crm_resource -r <リソースID> -W 2> /dev/null | grep " <マシンのホスト名> "」
-    #      の結果が"resource <リソースID> is running on: <マシンのホスト名> "である
+    #     「crm_resource -r <リソースID> -W 2> /dev/null | grep " <マシンのホスト名>"」
+    #      の結果が"resource <リソースID> is running on: <マシンのホスト名>"である
     ##
 
     @resource_id = split(/\s*,\s*/, $resource_id);
     $array_num = scalar(@resource_id);
     
     foreach my $id (@resource_id){
-        $result = `$CRM_RESOURCE -r $id -W 2> /dev/null | $GREP \" $my_node \"`;
+        $result = `$CRM_RESOURCE -r $id -W 2> /dev/null | $GREP \" $my_node\"`;
         chomp $result;
-        if ($result eq "resource $id is running on: $my_node "){
+        if ($result eq "resource $id is running on: $my_node"){
             $resource_check_count ++;
         }
     }
@@ -902,7 +902,7 @@ sub check_support_version {
 
     # Pacemaker がサポート対象バージョンであるかを確認する
     @version_factor = split(/\./, get_pm_version());
-    if (!($version_factor[0] == 2 && $version_factor[1] == 0)){
+    if (!($version_factor[0] == 2)){
         printlog("ERROR", COMMON_MS0038, get_pm_version());
     }
 
